#!/bin/perl
#################################################################################
# Created       : Martin Foster
# Modified      : 03/05/2001
#################################################################################
#
# Realm Configuration - Script part of Webchat designed to add/remove realms
# Copyright (C) 2000-2001  Martin Foster
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
# Author of this script can be contacted at the following:
#       E-Mail  : mfoster@redwhite.com
#       Address : Suite 209 - 355 5th Ave NE
#                 Calgary, Alberta
#                 T2E 0K9
#
#################################################################################

use CGI qw(:standard);						# Common gateway interface
use CGI::Carp qw(fatalsToBrowser);				# CGI Error logs
use strict;							# Strict variable enforcement

use Webchat::Database;						# Database handler
use Webchat::Date;						# Date handler
use Webchat::Login;						# Login functionality
use Webchat::Param;						# Parameter control
use Webchat::Table;						# Table handle


#################################################################################
# Data Members
#################################################################################
my $Database;							# Database handle
my $cgi;							# Common gateway interface handle

my %config;							# System hash
my %param;							# Parameter hash


#################################################################################
# Program Area
#################################################################################

	$cgi = new CGI;						# Create CGI Handle

	Webchat::Database::DatabaseConnect(\$Database);		# Connect to MySQL
	Webchat::Param::GetParam($cgi, \%param);		# Retreive parameters

	print $cgi->header();					# File header
	Webchat::Database::DocumentGetHeader($Database);        # HTML header

	# Login
	if (Webchat::Login::GetVerificationAdmin($Database, $cgi, \%param))
	{
		print $cgi->h1('Realm Administration'), "\n";	# Document title

		# Realm additions
		if (defined($param{'ADDITION'}))
		{ RealmAddition($Database, $cgi, \%param); }

		# Realms displays
		elsif (defined($param{'REALMTYPE'}))
		{ RealmDisplay($Database, $cgi, \%param); }

		# Selection
	 	else 
		{ RealmType($Database, $cgi, \%param); }
	}

	Webchat::Database::DocumentGetFooter($Database);	# HTML Footer
	$Database->disconnect();				# Disconnect from database


#################################################################################
# Sub-Routines
#################################################################################

#####################
# Realm Addition
#
# Sub-routine that displays additions of new realms.

sub RealmAddition
{
	#####################
	# Data members
	my $Database = shift;					# Database handle
	my $cgi      = shift;					# CGI handle
	my $param    = shift;					# Parameter list

	my @radiolang   = qw(relaxed restricted);		# Language
	my @radioaccess = qw(relaxed restricted list);		# Access
	my @radioguest  = qw(yes no post);			# Guests
	my @radiotags   = qw(relaxed restricted);		# Tags

	# Initialize radio buttons
	my $radiolang   = $cgi->radio_group('NEWLANG',  \@radiolang,  $radiolang[0],  'true');
	my $radioaccess = $cgi->radio_group('NEWACCESS',\@radioaccess,$radioaccess[0],'true');
	my $radioguest  = $cgi->radio_group('NEWGUEST', \@radioguest, $radioguest[0], 'true');
	my $radiotags   = $cgi->radio_group('NEWTAGS',  \@radiotags,  $radiotags[0],  'true');

	
	#####################
	# Program area

	# Cleanup
	delete $param->{'ADDITION'};

	print "\t", $cgi->hr, "\n";				# Horizontal row
	print $cgi->start_form();				# Begnning HTML form

	# Prompt and display realm name
	Webchat::Table::MakeTop($cgi);
	Webchat::Table::MakeValid($cgi, '<B>Realm Name</B>',   $cgi->textfield('NEWNAME'  , '', 20, 30));
	Webchat::Table::MakeValid($cgi, '<B>Image Height</B>', $cgi->textfield('NEWHEIGHT', '0', 20, 5));
	Webchat::Table::MakeValid($cgi, '<B>Image Width</B>',  $cgi->textfield('NEWWIDTH' , '0', 20, 5));
	Webchat::Table::MakeBlank($cgi);			# Spacer

	# Language selection
	Webchat::Table::MakeValid($cgi, '<B>Language</B>',        $radiolang);
	Webchat::Table::MakeBlank($cgi);			# Spacer

	# Access type
	Webchat::Table::MakeValid($cgi, '<B>Access type</B>',     $radioaccess);
	Webchat::Table::MakeBlank($cgi);			# Spacer

	# Guest access
	Webchat::Table::MakeValid($cgi, '<B>Guest Access</B>',    $radioguest);
	Webchat::Table::MakeBlank($cgi);			# Spacer

	# Tag enforcement
	Webchat::Table::MakeValid($cgi, '<B>Tag enforcement</B>', $radiotags);
	Webchat::Table::MakeBlank($cgi);			# Spacer

	# Submit and reset
	Webchat::Table::MakeValid($cgi, $cgi->submit('Add'), $cgi->reset('Clear'));
	Webchat::Table::MakeBottom($cgi);

	Webchat::Param::EmbedNormal($Database, $cgi, %{$param});

	print $cgi->end_form(), "\n";				# Ending HTML form
	print "\t", $cgi->hr, "\n";				# Horizontal row


}

#####################
# RealmDisplay
#
# Sub-routine that will display and handle basic operations reguarding direction
# of calls.   As in remove and additions.

sub RealmDisplay
{
	#####################
	# Data members
	my $Database = shift;					# Database handle
	my $Statement; 						# Statement shift

	my $cgi      = shift;					# CGI handle
	my $param    = shift;					# Parameter list reference

	my $color    = 0;					# Colour changer
	my $url      = $cgi->url();				# Self referencing URL

	my $in_back;						# Back button inline
	my $in_add;						# Inline button inline

	my @values;						# Received values


	#####################
	# Program area

	# Data removal
	if (defined( $param->{'DELETE'} ))
	{
		# Remove from satellite tables
		$Database->do("DELETE FROM PuppeteerRestriction WHERE RealmName=?", {}, $param->{'DELETE'});
		$Database->do("DELETE FROM PuppetInvitation WHERE RealmName=?", {}, $param->{'DELETE'});
		$Database->do("DELETE FROM RealmSupervisor WHERE RealmName=?", {}, $param->{'DELETE'});
		$Database->do("DELETE FROM WordRestriction WHERE RealmName=?", {}, $param->{'DELETE'});
		$Database->do("DELETE FROM Board WHERE RealmName=?", {}, $param->{'DELETE'});

		# Delete parent table
		$Database->do("DELETE FROM Realm WHERE RealmName=?", {}, $param->{'DELETE'});

		# Cleanup
		delete $param->{'DELETE'};
	}

	# Data addition
	if (defined( $param->{'NEWNAME'} ))
	{
		# Execute
		$Database->do("INSERT INTO Realm 
			(RealmName,
			 RealmLanguage,
			 RealmAccess,
			 RealmGuests,
			 RealmPublic,
			 RealmTags,
			 RealmImageHeight,
			 RealmImageWidth,
			 RealmTimestamp)
			VALUES (?,?,?,?,?,?,?,?,?)", {}, 

		 $param->{'NEWNAME'}, 
		 $param->{'NEWLANG'},
		 $param->{'NEWACCESS'}, 
		 $param->{'NEWGUEST'},
		 'yes', 
		 $param->{'NEWTAGS'}, 
		 $param->{'NEWHEIGHT'},
		 $param->{'NEWWIDTH'}, 
		 time);

		# Cleanup
		delete $param->{'NEWNAME'};
	}

	# Links
	# Generate inline
	($in_back) = Webchat::Param::EmbedInline($Database, $cgi, 'USER', $param->{'USER'}, 'CRYPT', $param->{'CRYPT'});
	($in_add)  = Webchat::Param::EmbedInline($Database, $cgi, %{$param}, 'ADDITION', 'True');

	print "<CENTER><P>",
	      "<A HREF=\"$url$in_back\">[Back]</A> ",
	      "<A HREF=\"$url$in_add\">[Addition]</A>",
	      "</P</CENTER>";

	# Data viewing
	# Prepare and execute
	$Statement = $Database->prepare("SELECT RealmName, 
		 RealmLanguage, 
		 RealmAccess, 
		 RealmGuests, 
		 RealmTags, 
		 RealmTimestamp 
		FROM  Realm 
		WHERE RealmPublic=? 
		ORDER BY RealmName");
	$Statement->execute($param->{'REALMTYPE'});

	print "<TABLE WIDTH=\"100%\">";

	# Display header
	print "\t<TR>\n";
	print "\t\t<TD><B>Realm Name</B></TD>\n";
	print "\t\t<TD WIDTH=\"50\"><B>Language</B></TD>\n";
	print "\t\t<TD WIDTH=\"50\"><B>Access</B></TD>\n";
	print "\t\t<TD WIDTH=\"50\"><B>Guests</B></TD>\n";
	print "\t\t<TD WIDTH=\"50\"><B>Tags</B></TD>\n";
	print "\t\t<TD WIDTH=\"50\"><B>Creation</B></TD>\n";
	print "\t\t<TD></TD>\n";
	print "\t</TR>\n";

	# Fetch rows of data
	while (@values = $Statement->fetchrow())
	{
		# Determin colour of row
		if ($color != 0)				# White
		{ print "\t<TR>\n"; $color = 0; }
		else						# Pale grey
		{ print "\t<TR BGCOLOR=\"\#999999\">\n";  $color = 1; }

		print "\t\t<TD><B>$values[0]</B></TD>\n";
		print "\t\t<TD><I>$values[1]</I></TD>\n";
		print "\t\t<TD><I>$values[2]</I></TD>\n";
		print "\t\t<TD><I>$values[3]</I></TD>\n";
		print "\t\t<TD><I>$values[4]</I></TD>\n";
		print "\t\t<TD><I>", Webchat::Date::GetDate($values[5]), "</I></TD>\n";

		print "\t\t", $cgi->start_form();		# Start form
		Webchat::Param::EmbedNormal($Database, $cgi, %{$param}, 'DELETE', $values[0]);

		print "\t\t<TD>\n";
		print "\t\t\t", $cgi->submit('Remove'), "\n";
		print "\t\t</TD>\n";
		print "\t\t", $cgi->end_form(), "\n";		# End form

		print "\t</TR>\n";				# End row
	}

	$Statement->finish();					# Finish SQL statement
	print "</TABLE>\n";					# End of table
}


#####################
# Realm Type
#
# Simply allows the user to determine which type of rooms to view private or 
# public based on a simple statement.

sub RealmType						# Database, CGI
{
	#####################
	# Data members
	my $Database = shift;					# Database handle
	my $cgi      = shift;					# CGI handle
	my $param    = shift;					# Parameter list

	my $list;	
	my @list     = qw(yes no);				# List of choices


	#####################
	# Program area
		
	print "\t", $cgi->hr, "\n";				# Horizontal row
	print $cgi->start_form();				# Begnning HTML form

	# Prepare list
	$list = $cgi->radio_group('REALMTYPE', \@list, $list[0], 'true');

	# Prompt and Display Document choices
	Webchat::Table::MakeTop($cgi);
	Webchat::Table::MakeValid($cgi, '<B>Public Realm</B>', $list);
	Webchat::Table::MakeBlank($cgi);			# Spacer

	Webchat::Table::MakeValid($cgi, $cgi->submit('List Realms'), ' ');
	Webchat::Table::MakeBottom($cgi);

	Webchat::Param::EmbedNormal($Database, $cgi, %{$param});

	print $cgi->end_form(), "\n";				# Ending HTML form
}
